@@ -103,6 +103,7 @@ char *command_line = 0;			// what is typed
 int  opt_quiet = 0;
 int  opt_silent = 0;
 int  opt_beeps  = 1;			// beep when done
+int  opt_recover_scan = 0;
 int  opt_error_mode = 0;
 int  opt_retry_count = 5;
 int  opt_reverse = 0;
@@ -181,6 +182,7 @@ void usage()
 
     bold("\nExisting File Options:\n");
     printf("  --append, -a          -- Append to existing file\n");
+    printf("   NOTE: --append is not yet implemented.\n");
     printf("  --zap, -z             -- Erase outfile(s) before writing\n");
 
     bold("\nRaw Output Options:\n");
@@ -228,6 +230,9 @@ void usage()
     printf("  --error=1  -e1  -- Stop reading at first error.\n");
     printf("  --retry=nn -tnn -- change retry count from 5 to nn\n");
     printf("  --reverse, -V   -- Scan in reverse to the beginning.\n");
+    printf("  --recover-scan, -c   -- Starting with an AFF file that has been partially \n");
+    printf("                     acquired, try to read each page, 8 sectors at a time.\n");
+    printf("                     (implies --append)\n");
 
     bold("\nOther:\n");
     printf("  --help, -h      -- Print this message.\n");
@@ -297,6 +302,7 @@ static struct option longopts[] = {
     { "no_ifconfig",   no_argument,        NULL, 'I'},
     { "batch",         no_argument,        NULL, 'Y'},
     { "skip",          required_argument,  NULL, 'k'},
+    { "recover-scan",  no_argument,        NULL, 'c'},
     {0,0,0,0}
 };
 
@@ -535,7 +541,7 @@ int checkpid(int pid)
 {
     char buf[1024];
     int  found = 0;
-    sprintf(buf,"ps %d",pid);
+    snprintf(buf,sizeof(buf),"ps %d",pid);
     FILE *f = popen(buf,"r");
     while(!feof(f)){
 	char *cc = buf;
@@ -559,7 +565,7 @@ int getlock(class imager *im)
      * can't get the lock.
      */
     char lockfile[MAXPATHLEN];
-    sprintf(lockfile,"/tmp/aimge.%s.lock",im->infile);
+    snprintf(lockfile,sizeof(lockfile),"/tmp/aimge.%s.lock",im->infile);
     if(access(lockfile,F_OK)==0){
 	/* Lockfile exists. Get it's pid */
 	char buf[1024];
@@ -582,7 +588,7 @@ int getlock(class imager *im)
     }
     FILE *f = fopen(lockfile,"w");
     if(!f){
-	err(1,lockfile);
+	err(1,"%s",lockfile);
     }
     fprintf(f,"%d\n",getpid());		// save our PID.
     fclose(f);
@@ -593,11 +599,11 @@ void open_logfile(const char *ifn)
 {
     /* Open the logfile, interperting ~ if necessary. */
     if(ifn[0]=='~' && ifn[1]=='/'){
-	strcpy(logfile_fname,getenv("HOME"));
-	strcat(logfile_fname,ifn+1);
+	strlcpy(logfile_fname,getenv("HOME"),sizeof(logfile_fname));
+	strlcat(logfile_fname,ifn+1,sizeof(logfile_fname));
     }
     else {
-	strcpy(logfile_fname,ifn);
+	strlcpy(logfile_fname,ifn,sizeof(logfile_fname));
     }
     logfile = fopen(logfile_fname,"a");
 }
@@ -661,6 +667,7 @@ void process_option(class imager *im,char ch,char *optarg)
     case 'Q': opt_silent++;		break;
     case 'R': opt_readsectors = atoi(optarg); break;
     case 'z': opt_zap ++;		break;
+    case 'c': opt_recover_scan++; opt_append++; break;
     case 'k':
 	opt_skip  = atoi(optarg);
 	if(lastchar(optarg)=='s'){
@@ -842,8 +849,7 @@ int main(int argc,char **argv)
 	 */
 	if(argc>0){
 	    if(im->fname_aff[0] || im->fname_raw[0]){
-		err(1,"two outputs are provided for input file %s",
-		    im->infile);
+		err(1,"two outputs are provided for input file %s", im->infile);
 	    }
 	    process_option(im,'o',*argv);
 	    argv++;
@@ -876,17 +882,25 @@ int main(int argc,char **argv)
 	if(!opt_append){
 	    if(access(im->fname_raw,F_OK)==0) errx(1,"%s: file exists",im->fname_raw);
 	    if(access(im->fname_aff,F_OK)==0) errx(1,"%s: file exists",im->fname_aff);
-	    /* If an AFM file is being created and the .000 file exists, generate an error */
+
+	    /* If an AFM file is being created and the .000 file exists,
+	     * generate an error
+	     */
 	    if(af_ext_is(im->fname_aff,"afm")){
 		char file000[MAXPATHLEN+1];
-		strcpy(file000,im->fname_aff);
+		strlcpy(file000,im->fname_aff,sizeof(file000));
 		char *cc = rindex(file000,'.');
 		if(!cc) err(1,"Cannot file '.' in %s\n",file000);
 		for(int i=0;i<2;i++){
-		    sprintf(cc,".%03d",i);
+		    char buf[16];
+		    snprintf(buf,sizeof(buf),".%03d",i);
+		    *cc = '\000';	// truncate
+		    strlcat(file000,buf,sizeof(file000)); // and concatenate
 		    if(access(file000,F_OK)==0){
-			fprintf(stderr,"%s: file exists. Delete it before converting.\n",file000);
-			fprintf(stderr,"NOTE: -z option will not delete %s\n",file000);
+			fprintf(stderr,"%s: file exists. Delete it before converting.\n",
+				file000);
+			fprintf(stderr,"NOTE: -z option will not delete %s\n",
+				file000);
 			return -1;
 		    }
 		}
