@@ -106,6 +106,8 @@ extern int opt_maxsize;
 extern char *command_line;
 extern int opt_no_dmesg;
 extern int opt_no_ifconfig;
+extern int opt_append;
+extern int opt_recover_scan;
 
 /* Current imager */
 extern imager **imagers;
