@@ -171,7 +171,7 @@ void imager::ident()
       
 	while(!feof(f)){
 	    if(fgets(buf,sizeof(buf),f)){
-		strcat(capbuf,buf);
+		strlcat(capbuf,buf,sizeof(capbuf));
 		char *cc = index(buf,'>'); // see if it should be terminated
 		if(cc) *cc = 0;
 		sprintf(checkbuf,"pass%d: <",scsi_pass);
@@ -204,7 +204,7 @@ void imager::ident()
 	while(!feof(f)){
 	    if(fgets(buf,sizeof(buf),f)){
 		buf[sizeof(buf)-1] = 0;	// make sure it is null-terminated
-		strcat(capbuf,buf);
+		strlcat(capbuf,buf,sizeof(capbuf));
 		checkline("device model",AF_DEVICE_MODEL,buf,device_model,af,0);
 		checkline("serial number",AF_DEVICE_SN,buf,serial_number,af,0);
 		checkline("firmware revision",AF_DEVICE_FIRMWARE,buf,firmware_revision,af,0);
@@ -289,23 +289,24 @@ int  scsi_attach(char *fname,int fname_len,
 
 #ifdef linux
 #include <dirent.h>
-void getfile(const char *dirname,const char *filename,char *copy,AFFILE *af,char *segname)
+static void getfile(const char *dirname,const char *filename,char *copy,
+		    int copysize,
+		    AFFILE *af,char *segname)
 {
     char path[MAXPATHLEN];
     char buf[1024];
 
     /* Build the pathname we are supposed to get */
     memset(buf,0,sizeof(buf));
-    strcpy(path,dirname);
-    strcat(path,filename);
-    if(copy) copy[0] = 0;		// by default, nothing was found
+    strlcpy(path,dirname,sizeof(path));
+    strlcat(path,filename,sizeof(path));
     FILE *f = fopen(path,"r");
     if(f){
 	if(fgets(buf,sizeof(buf),f)){
 	    char *cc = rindex(buf,'\n');
 	    if(cc) *cc = '\000';	// remove trailing \n
 	    ident_update_seg(af,segname,buf,0);
-	    if(copy) strcat(copy,buf);	
+	    if(copy) strlcat(copy,buf,copysize);	
 	}
 	fclose(f);
     }
@@ -344,13 +345,13 @@ void imager::ident()
 	while((dp = readdir(dir))!=0){
 	    if(dp->d_name[0]=='.') continue; // skip the dot names
 	    char dirname[MAXPATHLEN];
-	    strcpy(dirname,"/sys/bus/scsi/devices/");
-	    strcat(dirname,dp->d_name);
+	    strlcpy(dirname,"/sys/bus/scsi/devices/",sizeof(dirname));
+	    strlcat(dirname,dp->d_name,sizeof(dirname));
 
 	    char devname[MAXPATHLEN];
-	    strcpy(devname,dirname);
-	    strcat(devname,"/");
-	    strcat(devname,"/block");
+	    strlcpy(devname,dirname,sizeof(devname));
+	    strlcat(devname,"/",sizeof(devname));
+	    strlcat(devname,"/block",sizeof(devname));
 
 	    /* If this is a link, then stat it */
 	    char path[MAXPATHLEN];
@@ -363,15 +364,18 @@ void imager::ident()
 		     * Use it to find the directory where the USB information is stored.
 		     */
 		    char usbdir[MAXPATHLEN];
-		    strcpy(usbdir,dirname);
-		    strcat(usbdir,"/../../../../");
+		    strlcpy(usbdir,dirname,sizeof(usbdir));
+		    strlcat(usbdir,"/../../../../",sizeof(usbdir));
 		    device_model[0] = 0;
 		    serial_number[0] = 0;
-		    getfile(usbdir,"manufacturer",device_model,af,AF_DEVICE_MANUFACTURER);
-		    strcat(device_model," ");
-		    getfile(usbdir,"product",device_model,af,AF_DEVICE_MODEL);
-		    getfile(usbdir,"serial",serial_number,af,AF_DEVICE_SN);
-		    getfile(usbdir,"version",0,af,AF_DEVICE_FIRMWARE);
+		    getfile(usbdir,"manufacturer",device_model,sizeof(device_model),
+			    af,AF_DEVICE_MANUFACTURER);
+		    strlcat(device_model," ",sizeof(device_model));
+		    getfile(usbdir,"product",device_model,sizeof(device_model),
+			    af,AF_DEVICE_MODEL);
+		    getfile(usbdir,"serial",serial_number,sizeof(serial_number),
+			    af,AF_DEVICE_SN);
+		    //getfile(usbdir,"version",0,0,af,AF_DEVICE_FIRMWARE);
 		    return;		// we have successfully identified the device
 		}
 	    }
@@ -381,13 +385,14 @@ void imager::ident()
 	if(access(infile,R_OK)==0){
 	    char capbuf[65536];
 	    char buf[256];
-	    sprintf(buf,"hdparm -I %s",infile);
+	    if(af_hasmeta(infile)) return;	// something is wrong here
+	    snprintf(buf,sizeof(buf),"hdparm -I %s",infile);
 	    capbuf[0] = 0;
 	    FILE *f = popen(buf,"r");
 	    while(!feof(f)){
 		if(fgets(buf,sizeof(buf),f)){
 		    buf[sizeof(buf)-1] = 0;	// make sure it is null-terminated
-		    strcat(capbuf,buf);	// append to the buffer
+		    strlcat(capbuf,buf,sizeof(capbuf));	// append to the buffer
 		    
 		    /* Now check for each of the lines */
 		    checkline("Model Number:",AF_DEVICE_MODEL,buf,device_model,af,0);
@@ -411,11 +416,16 @@ void imager::ident()
  * Here are some parameters you may find interesting:
  *       hdparm -R 0x1700 0 0 /dev/hda   (to remove /dev/hda)
  *       ide2: BM-DMA at 0xb800-0xb807, BIOS settings: hde:DMA, hdf:pio
+ * Unfortunately, I can't get Linux ATA attach to work. Can you?
+ * Note: "These mknod calls should be eliminated. If this is not possible,
+ * a secure sub-directory should be created to hold them, and
+ * umask() should be called to control access." --- VSecurity
  */
-/* Linux ata attach commands. This should work but, in my experience, it doesn't.  */
 #define MAKE_ATA_ATTACH_COMMANDS_DEFINED
 void make_ata_attach_commands(char *attach,char *detach,char *master,char *slave,int dev)
 {
+#if 0
+
     system("/sbin/mknod /tmp/hda c  3 0");
     system("/sbin/mknod /tmp/hdb c  3 64");
     system("/sbin/mknod /tmp/hdc c 22 0");
@@ -424,6 +434,7 @@ void make_ata_attach_commands(char *attach,char *detach,char *master,char *slave
     sprintf(detach,"hdparm -U %d",dev);
     sprintf(master,"/dev/ad%d",dev*2);
     sprintf(slave,"/dev/ad%d",dev*2+1);
+#endif
 }
 
 /* Linux scsi attach commands */
@@ -475,7 +486,7 @@ void imager::ident()
 	char buf[65536];
 	char looking[65536];
 
-	sprintf(looking,"BSD Name: %s",name);
+	snprintf(looking,sizeof(looking),"BSD Name: %s",name);
 	FILE *f = popen("system_profiler SPUSBDataType","r");
 	while(get_block(f,buf,sizeof(buf))){
 	    if(strstr(buf,looking)){	// did I find the block I'm looking for?
