@@ -102,8 +102,8 @@ char *getfileline(const char *dirname,const char *filename)
     char path[MAXPATHLEN];
 
     /* Build the pathname we are supposed to get */
-    strcpy(path,dirname);
-    strcat(path,filename);
+    strlcpy(path,dirname,sizeof(path));
+    strlcat(path,filename,sizeof(path));
     FILE *f = fopen(path,"r");
     if(f){
 	char *buf = (char *)calloc(1,1024);
@@ -118,6 +118,8 @@ char *getfileline(const char *dirname,const char *filename)
     return 0;
 }
 
+
+
 int ident::get_params()
 {
     /* Is this a regular file? If so, just return */
@@ -139,7 +141,7 @@ int ident::get_params()
 	char *cc;
 	char sdname[MAXPATHLEN];
 	memset(sdname,0,sizeof(sdname));
-	strcpy(sdname,filename+5);
+	strlcpy(sdname,filename+5,sizeof(sdname));
 	/* If a partition name was provided, eliminate it */
 	for(cc=sdname;*cc;cc++){
 	    if(isdigit(*cc)){
@@ -153,13 +155,13 @@ int ident::get_params()
 	while((dp = readdir(dir))!=0){
 	    if(dp->d_name[0]=='.') continue; // skip the dot names
 	    char dirname[MAXPATHLEN];
-	    strcpy(dirname,"/sys/bus/scsi/devices/");
-	    strcat(dirname,dp->d_name);
+	    strlcpy(dirname,"/sys/bus/scsi/devices/",sizeof(dirname));
+	    strlcat(dirname,dp->d_name,sizeof(dirname));
 
 	    char devname[MAXPATHLEN];
-	    strcpy(devname,dirname);
-	    strcat(devname,"/");
-	    strcat(devname,"/block");
+	    strlcpy(devname,dirname,sizeof(devname));
+	    strlcat(devname,"/",sizeof(devname));
+	    strlcat(devname,"/block",sizeof(devname));
 
 	    /* If this is a link, then stat it */
 	    char path[MAXPATHLEN];
@@ -172,8 +174,8 @@ int ident::get_params()
 		     * Use it to find the directory where the USB information is stored.
 		     */
 		    char usbdir[MAXPATHLEN];
-		    strcpy(usbdir,dirname);
-		    strcat(usbdir,"/../../../../");
+		    strlcpy(usbdir,dirname,sizeof(usbdir));
+		    strlcat(usbdir,"/../../../../",sizeof(usbdir));
 		    params.manufacturer  = getfileline(usbdir,"manufacturer");
 		    params.model         = getfileline(usbdir,"product");
 		    params.sn            = getfileline(usbdir,"serial");
@@ -187,13 +189,14 @@ int ident::get_params()
 	if(access(filename,R_OK)==0){
 	    char capbuf[65536];
 	    char buf[256];
-	    sprintf(buf,"hdparm -I %s",filename);
+	    if(af_hasmeta(filename)) return -1;
+	    snprintf(buf,sizeof(buf),"hdparm -I %s",filename);
 	    capbuf[0] = 0;
 	    FILE *f = popen(buf,"r");
 	    while(!feof(f)){
 		if(fgets(buf,sizeof(buf),f)){
 		    buf[sizeof(buf)-1] = 0;	// make sure it is null-terminated
-		    strcat(capbuf,buf);	// append to the buffer
+		    strlcat(capbuf,buf,sizeof(capbuf));	// append to the buffer
 		    
 		    /* Now check for each of the lines */
 		    params.model    = getvalue("Model Number:",buf);
@@ -292,9 +295,9 @@ int in_path(const char *cmd)
     char *last = 0;
     while((check = strtok_r(pathi,":",&last))!=0){
 	char buf[MAXPATHLEN+1];
-	strcpy(buf,check);
-	strcat(buf,"/");
-	strcat(buf,cmd);
+	strlcpy(buf,check,sizeof(buf));
+	strlcat(buf,"/",sizeof(buf));
+	strlcat(buf,cmd,sizeof(buf));
 	if(access(buf,R_OK)==0){
 	    free(path);
 	    return 1;
