@@ -166,7 +166,7 @@ void imager::write_data(unsigned char *buf,uint64 offset,int len)
 
     /* Write it out and carry on... */
     if(af){
-	af_seek(af,offset,SEEK_SET);
+	if(offset) af_seek(af,offset,SEEK_SET);
 	if(af_write(af,buf,len)!=len){
 	    perror("af_write");	// this is bad
 	    af_close(af);	// try to gracefully recover
@@ -176,7 +176,7 @@ void imager::write_data(unsigned char *buf,uint64 offset,int len)
 	}
     }
     if(fout){
-	fseeko(fout,offset,SEEK_SET);
+	if(offset) fseeko(fout,offset,SEEK_SET);
 	if(fwrite(buf,1,len,fout)!=(unsigned)len){
 	    perror("fwrite");	// this is also bad
 	    fclose(fout);	// get what we can out to disk
@@ -365,7 +365,6 @@ void imager::image_loop(uint64 low_water_mark, // sector # to start
 	}
 	else {
 	    assert(high_water_mark != 0); // we can't go backwards if we don't know end
-
 	    snum = high_water_mark - sectors_to_read;
 	    if(snum<low_water_mark){
 		snum = low_water_mark;
@@ -377,13 +376,13 @@ void imager::image_loop(uint64 low_water_mark, // sector # to start
 	last_sectors_read = sectors_to_read;
 	last_direction = direction;
 
-	if (high_water_mark != 0) // otherwise just sum
-		data_offset = sector_size * snum; // where we want to start reading
+	if (high_water_mark != 0){ 	// if we know where the top is...
+	    data_offset = sector_size * snum; // where we want to start reading
 
-
-	if(data_offset != in_pos){	// eliminate unnecessary seeks
-	    lseek(in,data_offset,SEEK_SET); // make sure we are at the right place; (ignore error)
-	    in_pos = data_offset;
+	    if(data_offset != in_pos){	// eliminate unnecessary seeks
+		lseek(in,data_offset,SEEK_SET);	// make sure we are at the right place; (ignore error)
+		in_pos = data_offset;
+	    }
 	}
 
 	status();			// tell the user what we are doing
@@ -627,6 +626,67 @@ void imager::hash_setup()
 }
 
 
+/* start_recover_scan():
+ * Do a recover scan...
+ * Try to read all of the pages that are not in the image
+ */
+void imager::start_recover_scan()
+{
+    if(total_sectors==0){
+	err(1,"total_sectors not set. Cannot proceed with recover_scan");
+    }
+    if(af->image_sectorsize==0){
+	err(1,"af->image_sectorsize not set. Cannot proceed with recover_scan");
+    }
+    if(af->image_pagesize==0){
+	err(1,"af->image_pagesize not set. Cannot proceed with recover_scan");
+    }
+
+    int64 sectors_per_page = af->image_pagesize / af->image_sectorsize;
+    int64 num_pages = (total_sectors+sectors_per_page-1) / sectors_per_page;
+    int *pages = (int *)calloc(sizeof(int *),num_pages);
+    printf("There are %qd pages... Checking to see which are in image...\n");
+    /* Now figure out which pages we have.
+     * This only works with true AFF files, because we go directly to the TOC cache.
+     */
+    for(int64 i=0;i<num_pages;i++){
+	char segname[AF_MAX_NAME_LEN];
+	snprintf(segname,sizeof(segname),AF_PAGE,i);
+	if(af_toc(af,segname)){
+	    printf("Page %qd is in the image...\r",i);
+	    pages[i]=1; // note that we have this page
+	}
+    }
+    /* Print the missing pages: */
+    int missing_pages = 0;
+    printf("Missing pages:\n");
+    for(int64 i=0;i<num_pages;i++){
+	if(pages[i]==0){
+	    printf("%qd ",i);
+	    missing_pages++;
+	}
+    }
+    printf("\n");
+    printf("Total missing pages: %d\n",missing_pages);
+    /* Now randomly try to get each of the missing pages */
+#ifdef HAVE_SRANDOMDEV
+    srandomdev();
+#endif
+    while(missing_pages>0){
+	int random_page = random() % num_pages;
+	while(pages[random_page]!=0) random_page = (++random_page) % num_pages;
+	printf("*** try for page %d\n",random_page);
+	uint64 start_sector = random_page * sectors_per_page;
+	uint64 end_sector   = start_sector + sectors_per_page;
+	image_loop(start_sector,end_sector,1,opt_readsectors,1);
+	pages[random_page] = 1;		// did that page
+	missing_pages--;
+    }
+    free(pages);
+    exit(0);
+}
+
+
 /* start_imaging2():
  * Actually run the imaging
  */
@@ -692,41 +752,57 @@ int imager::start_imaging()
 	af->tag = (void *)this;			// remember me!
 
 	/* If the segment size hasn't been set, then set it */
-	ident();			// ident the drive if possible
-	af_update_seg(af,AF_ACQUISITION_COMMAND_LINE,0,command_line,strlen(command_line));
-	af_update_seg(af,AF_ACQUISITION_DEVICE,0,infile,strlen(infile));
-	af_set_sectorsize(af,sector_size);
-	af_set_pagesize(af,opt_pagesize);	// sets current page size
-	if(opt_maxsize) af_set_maxsize(af,opt_maxsize);
-	if(total_sectors>0){
-	    af_update_segq(af,AF_DEVICE_SECTORS,(int64)total_sectors);
+
+	if(opt_append){
+	    /* Make sure that the AFF file is for this drive, and set it up */
+	}
+	else {
+	    ident();			// ident the drive if possible
+	    af_update_seg(af,AF_ACQUISITION_COMMAND_LINE,0,command_line,strlen(command_line));
+	    af_update_seg(af,AF_ACQUISITION_DEVICE,0,infile,strlen(infile));
+	    af_set_sectorsize(af,sector_size);
+	    af_set_pagesize(af,opt_pagesize);	// sets current page size
+	    if(opt_maxsize){
+		if(af_set_maxsize(af,opt_maxsize)){
+		    exit(-1);
+		}
+	    }
+	    if(total_sectors>0){
+		af_update_segq(af,AF_DEVICE_SECTORS,(int64)total_sectors);
+	    }
+	    if(opt_no_ifconfig==0){
+		char *macs = ident::mac_addresses();
+		if(macs){
+		    af_update_seg(af,AF_ACQUISITION_MACADDR,0,macs,strlen(macs));
+		    free(macs);
+		}
+	    }
+
+	    if(opt_no_dmesg==0){
+		char *dmesg = ident::dmesg();
+		if(dmesg && strlen(dmesg)){
+		    af_update_seg(af,AF_ACQUISITION_DMESG,0,dmesg,strlen(dmesg));
+		    free(dmesg);
+		}
+	    }
+	    if(af_get_seg(af,AF_IMAGE_GID,0,0,0)!=0){
+		unsigned char bit128[16];
+		RAND_pseudo_bytes(bit128,sizeof(bit128));
+		af_update_seg(af,AF_IMAGE_GID,0,bit128,sizeof(bit128));
+	    }
 	}
 	af_set_callback(af,segwrite_callback);
 
-	if(opt_no_ifconfig==0){
-	    char *macs = ident::mac_addresses();
-	    if(macs){
-		af_update_seg(af,AF_ACQUISITION_MACADDR,0,macs,strlen(macs));
-		free(macs);
-	    }
-	}
-
-	if(opt_no_dmesg==0){
-	    char *dmesg = ident::dmesg();
-	    if(dmesg && strlen(dmesg)){
-		af_update_seg(af,AF_ACQUISITION_DMESG,0,dmesg,strlen(dmesg));
-		free(dmesg);
-	    }
-	}
-
-	unsigned char bit128[16];
-	RAND_pseudo_bytes(bit128,sizeof(bit128));
-	af_update_seg(af,AF_IMAGE_GID,0,bit128,sizeof(bit128));
+	char timeseg[65536];
+	size_t datalen = sizeof(timeseg);
+	memset(timeseg,0,sizeof(timeseg));
+	af_get_seg(af,AF_ACQUISITION_DATE,0, (unsigned char *)timeseg,&datalen);
 
 	time_t t = time(0);
 	char timebuf[64];
-	strftime(timebuf,sizeof(timebuf),"%Y-%m-%d %H:%M:%S",localtime(&t));
-	af_update_seg(af,AF_ACQUISITION_DATE,0,timebuf,strlen(timebuf));
+	strftime(timebuf,sizeof(timebuf),"%Y-%m-%d %H:%M:%S\n",localtime(&t));
+	strlcat(timeseg,timebuf,sizeof(timeseg));
+	af_update_seg(af,AF_ACQUISITION_DATE,0,timeseg,strlen(timeseg));
     }
 
     /* Here is where the imaging takes place.
@@ -741,7 +817,12 @@ int imager::start_imaging()
     }
     if(in!=FD_IDENT){
 	imaging_timer.start();
-	start_imaging2();
+	if(opt_recover_scan){
+	    start_recover_scan();
+	}
+	else{
+	    start_imaging2();
+	}
 	imaging_timer.stop();
     }
 
