@@ -158,6 +158,7 @@ typedef struct _AFFILE {
     FILE          *aseg;
     struct af_toc_mem *toc;		// table of contents
     int	           toc_count;	       // number of directory elements
+    unsigned int   disable_toc:1;	// true if ToC is not in use because of error
 
     /****************************************************************/
 
@@ -241,7 +242,7 @@ void	af_set_cachesize(AFFILE *af,int max); // how much memory can the cache use?
 
 
 /* navigating within the data segments as if they were a single file */
-int	af_read(AFFILE *af,unsigned char *buf,int count);
+int	af_read(AFFILE *af,unsigned char *buf,size_t count);
 uint64  af_seek(AFFILE *af,int64 pos,int whence); // returns new position
 uint64  af_tell(AFFILE *af);
 int	af_eof(AFFILE *af);		// is the virtual file at the end?
@@ -251,7 +252,7 @@ void	af_enable_writing(AFFILE *af,int flag);	// set true to enable writing; retu
 void	af_set_callback(AFFILE *af, void (*cb)(struct affcallback_info *acbi)); 
 void	af_enable_compression(AFFILE *af,int type,int level); // set/gunset compression for writing
 int	af_compression_type(AFFILE *af);
-int	af_write(AFFILE *af,unsigned char *buf,int count);
+int	af_write(AFFILE *af,unsigned char *buf,size_t count);
 const unsigned char
 	*af_badflag(AFFILE *af); // return the pattern used to identify bad sectors
 int	af_is_badsector(AFFILE *af,unsigned char *buf); // 0 if not, 1 if it is, -1 if error
@@ -275,7 +276,7 @@ int	af_is_badsector(AFFILE *af,unsigned char *buf); // 0 if not, 1 if it is, -1
 
 /* Misc. Functions */
 const char *af_ext(const char *filename);	// return the extension of str including the dot
-bool	    af_ext_is(const char *filename,const char *ext);
+int	    af_ext_is(const char *filename,const char *ext);
 const char *af_filename(AFFILE *af);	// returns the filename of an open stream.
 int	    af_identify(AFFILE *af);	// returns type of AFFILE pointer
 
