@@ -224,13 +224,14 @@ struct af_vnode {
     int (*update_seg)(AFFILE *af,const char *name,unsigned long arg,
 		      const void *value,unsigned int vallen);
     int (*del_seg)(AFFILE *af,const char *name);
-    int (*read)(AFFILE *af,unsigned char *buf,uint64 offset,int count);
-    int (*write)(AFFILE *af,unsigned char *buf,uint64 offset,int count);
+    int (*read)(AFFILE *af,unsigned char *buf,uint64 offset,size_t count);
+    int (*write)(AFFILE *af,unsigned char *buf,uint64 offset,size_t count);
 };
 
-#define AF_VNODE_TYPE_PRIMITIVE 0x01	// single-file implemntation
-#define AF_VNODE_TYPE_COMPOUND  0x02	// multi-file implemntation
+#define AF_VNODE_TYPE_PRIMITIVE 0x01	// single-file implementation 
+#define AF_VNODE_TYPE_COMPOUND  0x02	// multi-file implementation 
 #define AF_VNODE_TYPE_RELIABLE  0x04	// writes are reliable; no need to verify them.
+#define AF_VNODE_MAXSIZE_MULTIPLE 0x08  // maxsize must be multiple of pagesize (for AFM and splitraw)
 
 int af_vstat(AFFILE *af,struct af_vnode_info *vni); // does the stat
 
@@ -360,6 +361,7 @@ struct aff_pagebuf *af_cache_alloc(AFFILE *af,int64 pagenum);
  */
 uint64  af_decode_q(unsigned char buf[8]); // return buf[8] into an unsigned quad
 const char *af_commas(char buf[64],int64 val);
+int af_hasmeta(const char *buf);	// return 1 if buf has shell metacharacters
 
 #ifndef HAVE_STRLCPY
 size_t strlcpy(char *dest,const char *src,size_t dest_size);
