@@ -186,11 +186,15 @@ int af_get_page(AFFILE *af,int64 pagenum,unsigned char *data,size_t *bytes)
      * If we can't find it with new nomenclature, try the old one...
      */
     if(af_get_page_raw(af,pagenum,&arg,0,&page_len)){
-	/* Segment doesn't exist. Fill buffer with the 'bad segment' flag and return */
-	for(size_t i = 0;i <= af->image_pagesize - af->image_sectorsize;
-	    i+= af->image_sectorsize){
-	    memcpy(data+i,af->badflag,af->image_sectorsize);
-	    af->bytes_memcpy += af->image_sectorsize;
+	/* Segment doesn't exist.
+	 * If we have been provided with a buffer, fill buffer with the 'bad segment' flag and return.
+	 */
+	if (data) {
+	    for(size_t i = 0;i <= af->image_pagesize - af->image_sectorsize;
+		i+= af->image_sectorsize){
+		memcpy(data+i,af->badflag,af->image_sectorsize);
+		af->bytes_memcpy += af->image_sectorsize;
+	    }
 	}
 	return -1;			// segment doesn't exist
     }
