@@ -69,8 +69,10 @@ int af_set_maxsize(AFFILE *af,int64 maxsize)
 			      maxsize,af->image_sectorsize);
 	return -1;
     }
-    if((af->image_pagesize!=0) && (maxsize % af->image_pagesize != 0)){
-	(*af->error_reporter)("Cannot set maxsize to %"I64d" (pagesize=%d)\n",
+    if((af->image_pagesize!=0)
+       && (af->v->type & AF_VNODE_MAXSIZE_MULTIPLE)
+       && (maxsize % af->image_pagesize != 0)){
+	(*af->error_reporter)("Cannot set maxsize to %"I64d" --- not multiple of pagesize=%d\n",
 			      maxsize,af->image_pagesize);
 	return -1;
     }
@@ -98,7 +100,7 @@ int af_purge(AFFILE *af)
     return ret;
 }
 
-int af_read(AFFILE *af,unsigned char *buf,int count)
+int af_read(AFFILE *af,unsigned char *buf,size_t count)
 {
     if (af_trace) fprintf(af_trace,"af_read(%p,%p,%d) (pos=%"I64d")\n",af,buf,count,af->pos);
     if (af->v->read){			// bypass
@@ -173,14 +175,17 @@ int af_read(AFFILE *af,unsigned char *buf,int count)
  *
  */
 
-int af_write(AFFILE *af,unsigned char *buf,int count)
+int af_write(AFFILE *af,unsigned char *buf,size_t count)
 {
     if (!af->writing){
 	errno = EPERM;			// operation not permitted
 	return -1;			// not opened for writing
     }
 
-    if (af_trace) fprintf(af_trace,"af_write(%p,%p,%d)\n",af,buf,count);
+    if (af_trace){
+	fprintf(af_trace,"af_write(af=%p,buf=%p,count=%d) pos=%"I64d"\n",
+			  af,buf,count,af->pos);
+    }
     /* vnode write bypass:
      * If a write function is defined, use it and avoid the page and cache business. 
      */
