@@ -159,6 +159,23 @@ int64	af_segname_hash_page_number(const char *name,char *hash,int hashlen)
     return page;
 }
 
+int af_hasmeta(const char *infile)
+{
+    /* return 1 if the string has shell metacharacters */
+    for(const char *cc = infile;*cc;cc++){
+	switch(*cc){
+	case '?': return 1;
+	case '*': return 1;
+	case '&': return 1;
+	case '`': return 1;
+	case '(': return 1;
+	case ')': return 1;
+	}
+    }
+    return 0;
+}
+
+
 #ifndef HAVE_STRLCPY
 size_t strlcpy(char *dest,const char *src,size_t dest_size)
 {
