@@ -37,6 +37,35 @@ using namespace s3;
 #define BANDWIDTH_DEFAULT_SIZE 1000000
 int bandwidth_offset = 0;
 
+#ifndef HAVE_STRLCPY
+size_t strlcpy(char *dest,const char *src,size_t dest_size)
+{
+    strncpy(dest,src,dest_size);
+    dest[dest_size-1] = '\000';
+    return strlen(dest);
+}
+#endif
+
+#ifndef HAVE_STRLCAT
+size_t strlcat(char *dest,const char *src,size_t dest_size)
+{
+    int dest_len = strlen(dest);
+    int src_len  = strlen(src);
+    int room     = dest_size - (dest_len +src_len+1);
+    if(room>0){
+	/* There is room; just copy over what we have and return */
+	strcat(dest,src);
+	return strlen(dest);
+    }
+    /* Not room; figure out how many bytes we can copy... */
+    int left = dest_size - (dest_len+1);
+    strncpy(dest+dest_len,src,left);
+    dest[dest_len-1] = '\000';
+    return strlen(dest);
+}
+#endif
+
+
 /* Add commas
  */
 const char *af_commas(char buf[64],long long val)
@@ -59,10 +88,10 @@ const char *af_commas(char buf[64],long long val)
 	val = val / 1000;		// and shift what's over
 
 	if(val>0){			// we will still have more to do
-	    sprintf(tmp,",%03d",digits);	// so pad it with zeros and a comma
+	    snprintf(tmp,sizeof(tmp),",%03d",digits);	// so pad it with zeros and a comma
 	}
 	else {
-	    sprintf(tmp,"%d",digits);	// otherwise just get the value
+	    snprintf(tmp,sizeof(tmp),"%d",digits);	// otherwise just get the value
 	}
 	strcpy(t2,buf);			// copy out the buffer
 	strcpy(buf,tmp);		// copy in what we just did
@@ -119,7 +148,7 @@ void s3_ls(FILE *out,const char *prefix,cvector *cv)
 	    if(cv) cv->push_back(**i);
 	    /* Make date nice */
 	    char tstamp[64];
-	    strcpy(tstamp,(*i)->LastModified.c_str());
+	    strlcpy(tstamp,(*i)->LastModified.c_str(),sizeof(tstamp));
 	    tstamp[10] = ' ';
 	    tstamp[19] = '\000';
 	    
@@ -213,7 +242,7 @@ void s3_cp(const char *fname,string key)
      * Note that we do this with read, so that we can read from stdin
      */
     FILE *f = fopen(fname,"r");
-    if(!f) err(1,fname);
+    if(!f) err(1,"%s",fname);
     class response_buffer inbuf;
     while(!feof(f)){
 	char buf[65536];
@@ -263,7 +292,7 @@ void usage()
     printf("\n");
     printf("Debugging commands:\n");
     printf("s3 regress            - run regression tests\n");
-    printf("s3 bandwidth [-m] nn  - measure bandwidth (defaults to 'bandwidth' bucket)\n");
+    printf("s3 bandwidth [-m] nn  - measure bandwidth \n");
     printf("                      Use -m to make the files that are needed for read testing.\n");
     printf("\n");
     printf("Options:\n");
@@ -274,7 +303,8 @@ void usage()
     printf("   -O = set bandwidth offset (default 0)\n");
     printf("   -u url = go to url instead of %s\n",aws_base_url);
     printf("   -o fn = append output to file fn\n");
-    printf("   -v  verbose\n");
+    printf("   -V  verbose\n");
+    printf("   -v  print version number and exit\n");
     printf("   -t tag = tag to append to output\n");
     exit(0);
 }
@@ -288,8 +318,8 @@ int regress()
     for(int i=0;i<100;i++){
 	char name[1024];
 	char value[1024];
-	sprintf(name,"bucket%d",i);
-	sprintf(value,"This is the contents of bucket %d\n",i);
+	snprintf(name,sizeof(name),"bucket%d",i);
+	snprintf(value,sizeof(value),"This is the contents of bucket %d\n",i);
 	object_put(opt_bucket,name,value,strlen(value),0);
     }
 	
@@ -315,11 +345,10 @@ void s3_bandwidth(int argc,char **argv)
     int opt_write_test=1;
     const char *opt_url = 0;
 
-    FILE *out = outfile ? fopen(outfile,"a") : stdout;
-
     argc--;argv++;
 
     if(argc>0 && strcmp(argv[0],"-m")==0){
+	if(verbose) fprintf(stderr,"opt_make\n");
 	opt_make = 1;
 	argc--;
 	argv++;
@@ -337,24 +366,24 @@ void s3_bandwidth(int argc,char **argv)
 
     size_t size = BANDWIDTH_DEFAULT_SIZE;
     if(argc>0) size=atoi(argv[0]);
+    if(verbose) fprintf(stderr,"size=%d\n",size);
+    if(size==0) err(1,"size=0");
     char *buf = (char *)malloc(size);
+    if(!buf) err(1,"malloc");
     memset(buf,'E',size);
 
     if(argc>0) size=atoi(argv[0]);
-    if(s3_debug==0) s3_debug = 1;			// print retries
 
     if(strncmp(argv[0],"http://",7)==0){
 	opt_url = argv[0];
 	opt_write_test = 0;
     }
 
-
     char base[1024];
     char randp[1024];
-    sprintf(base,"%s.%d",BANDWIDTH_PREFIX,size);
-    sprintf(randp,"%s.%d.%d",BANDWIDTH_PREFIX,size,random() % 1000);
+    snprintf(base,sizeof(base),"%s.%d",BANDWIDTH_PREFIX,size);
+    snprintf(randp,sizeof(randp),"%s.%d.%d",BANDWIDTH_PREFIX,size,random() % 1000);
     
-    if(opt_make) strcpy(randp,base);		// just write to this one
 
     aftimer twrite;
 
@@ -362,8 +391,9 @@ void s3_bandwidth(int argc,char **argv)
 	/* Measure the write bandwidth */
 	twrite.start();
 
+	if(opt_make) strcpy(randp,base);		// just write to this one
 	char wkey[1024];
-	sprintf(wkey,"%s.%d",randp,bandwidth_offset);
+	snprintf(wkey,sizeof(wkey),"%s.%d",randp,bandwidth_offset);
 	object_put(opt_bucket,wkey,buf,size,0);
 	if(verbose) fprintf(stderr," wrote %s/%s\n",opt_bucket,wkey);
 	write_retry += s3_request_retry_count;
@@ -386,7 +416,7 @@ void s3_bandwidth(int argc,char **argv)
     tread.start();
 
     char rkey[1024];
-    sprintf(rkey,"%s.%d",base,bandwidth_offset);
+    snprintf(rkey,sizeof(rkey),"%s.%d",base,bandwidth_offset);
     response_buffer *r=0;
     
     if(opt_url==0){
@@ -403,19 +433,28 @@ void s3_bandwidth(int argc,char **argv)
     tread.stop();
     if(verbose) fprintf(stderr," read %s/%s\n",opt_bucket,rkey);
 
+    char line[1024];
+    memset(line,0,sizeof(line));
     time_t t = time(0);
     struct tm *tm = gmtime(&t);
     char tbuf[64];
     strftime(tbuf,sizeof(tbuf),"%F %T",tm);
+
+    char hextag[64];
+    memset(hextag,0,sizeof(hextag));
+    for(int i=0;i<16;i++){
+	sprintf(hextag+i*2,"%02x",r->ETag[i]);
+    }
+
+    FILE *out = outfile ? fopen(outfile,"a") : stdout;
+
+    //snprintf(line,sizeof(line),"v3: %s\t%d\t%d\t%f\t%f\t%d\t%d\t%d\t%s
     fprintf(out,"v3: %s\t",tbuf);
 
     fprintf(out,"%d\t%d\t",size,bandwidth_offset);
     fprintf(out,"%f\t",twrite.elapsed_seconds());
     fprintf(out,"%f\t",tread.elapsed_seconds());
     fprintf(out,"%d\t%d\t%d\t",write_retry,write_err,read_retry);
-    for(int i=0;i<16;i++){
-	fprintf(out,"%02x",r->ETag[i]);
-    }
     fprintf(out," ");
     /* Now verify the MD5 */
     unsigned char md5[16];
@@ -426,7 +465,7 @@ void s3_bandwidth(int argc,char **argv)
 	for(int i=0;i<16;i++) fprintf(out,"%02x",md5[i]);
     }
 
-    if(tag) fprintf(out," %d ",tag);
+    if(tag) fprintf(out,"\t%d ",tag);
     fprintf(out,"\n");
     fclose(out);
     if(r) delete r;
@@ -450,12 +489,12 @@ int main(int argc,char **argv)
 	case 'b': opt_bucket = optarg;break;
 	case 'f': opt_flag = atoi(optarg);break;
 	case 'm': opt_meta = 1;break;
-	case 'V':
+	case 'v':
 	    printf("%s version %s\n",argv[0],PACKAGE_VERSION);
 	    exit(0);
 	case 'u': aws_base_url = optarg;break;
 	case 'o': outfile = optarg;break;
-	case 'v': verbose++;break;
+	case 'V': verbose++;break;
 	case 't': tag = atoi(optarg);break;
 	case 'h':
 	case '?':
@@ -504,7 +543,6 @@ int main(int argc,char **argv)
     if(!strcmp(cmd,"regress")) {regress();exit(0);}
     if(!strcmp(cmd,"delp")) {s3_delp(argc,argv);exit(0);}
     if(!strcmp(cmd,"bandwidth")) {
-	opt_bucket = "bandwidth";
 	s3_bandwidth(argc,argv);exit(0);
     }
     usage();
