@@ -402,7 +402,7 @@ static int afd_open(AFFILE *af)
     while ((dp = readdir(dirp)) != NULL){
 	if (last4_is_aff(dp->d_name)){
 	    char path[MAXPATHLEN+1];
-	    strcpy(path,af->fname);
+	    strlcpy(path,af->fname,sizeof(path));
 	    strlcat(path,"/",sizeof(path));
 	    strlcat(path,dp->d_name,sizeof(path));
 	    if(afd_add_file(af,path)){
@@ -553,7 +553,7 @@ int afd_del_seg(AFFILE *af,const char *segname)
 
 struct af_vnode vnode_afd = {
     AF_IDENTIFY_AFD,		// 
-    AF_VNODE_TYPE_COMPOUND,		// 
+    AF_VNODE_TYPE_COMPOUND|AF_VNODE_TYPE_RELIABLE,		// 
     "AFF Directory",
     afd_identify_file,
     afd_open,			// open
