@@ -107,7 +107,7 @@ int aff_write_seg(AFFILE *af, const char *segname,unsigned long arg,const void *
  ****************************************************************/
 
 /* aff_get_segment:
- * Get the named segment, using the toc cache if it is present.
+ * Get the named segment, using the toc cache.
  * If there is no cache, 
  *  -  If the requested segment is the next segment, just get it.
  *  -  Otherwise go to the beginning and scan for it.
@@ -129,7 +129,19 @@ static int aff_get_seg(AFFILE *af,const char *name,
 
     if(adm){
 	fseeko(af->aseg,adm->offset,SEEK_SET);
+	int ret = af_get_next_seg(af,next,sizeof(next),arg,data,datalen);
+	assert(strcmp(next,name)==0);	// hopefully this is what they asked for
+	return ret;
     }
+    /* 2007-05-30: slg - if it is not in the TOC and we are using the TOC,
+     * then it is not in the file. Just return.
+     */
+    if(af->disable_toc==0) return -1;
+
+    /* This code searches through the file.
+     * This is what you have to do if there is no ToC.
+     * It's slow.*/
+
     do {
 	int r = af_probe_next_seg(af,next,sizeof(next),0,0,&segsize,1);
 	if(r==0 && strcmp(next,name)==0){	// found the segment!
@@ -505,7 +517,8 @@ static int aff_open(AFFILE *af)
 
     if(strcmp(buf,AF_HEADER)!=0){
 	buf[7] = 0;
-	(*af->error_reporter)("aff_open: %s is not an AFF file (header=%s)\n",af->fname,buf);
+	(*af->error_reporter)("aff_open: %s is not an AFF file (header=%s)\n",
+			      af->fname,buf);
 	return -1;
     }
 
@@ -574,7 +587,7 @@ static int aff_vstat(AFFILE *af,struct af_vnode_info *vni)
 
 struct af_vnode vnode_aff = {
     AF_IDENTIFY_AFF,
-    AF_VNODE_TYPE_PRIMITIVE,
+    AF_VNODE_TYPE_PRIMITIVE|AF_VNODE_TYPE_RELIABLE,
     "AFF",
     aff_identify_file,
     aff_open,
