@@ -77,8 +77,11 @@ static int s3_open(AFFILE *af)
     char bucket[1024]; memset(bucket,0,sizeof(bucket));
     char path[1024];   memset(path,0,sizeof(path));
 
-    memcpy(bucket,fn+match[1].rm_so,match[1].rm_eo-match[1].rm_so);
-    memcpy(path,fn+match[2].rm_so,match[2].rm_eo-match[2].rm_so);
+    int count = MIN(sizeof(bucket)-1,match[1].rm_eo-match[1].rm_so);
+    strncpy(bucket,fn+match[1].rm_so,count);
+
+    count = MIN(sizeof(path)-1,match[2].rm_eo-match[2].rm_so);
+    memcpy(path,fn+match[2].rm_so,count);
 
     if(strlen(bucket)==0){
 	const char *b = getenv(S3_DEFAULT_BUCKET);
