@@ -312,7 +312,7 @@ static int split_raw_vstat(AFFILE *af,struct af_vnode_info *vni)
     return 0;
 }
 
-static int split_raw_read(AFFILE *af, unsigned char *buf, uint64 pos,int count)
+static int split_raw_read(AFFILE *af, unsigned char *buf, uint64 pos,size_t count)
 {
     struct split_raw_private *srp = SPLIT_RAW_PRIVATE(af);
     off_t c3;
@@ -366,7 +366,7 @@ static int split_raw_read(AFFILE *af, unsigned char *buf, uint64 pos,int count)
  * and just seek to the last character and write a single NUL.
  */
 
-int split_raw_write_internal2(AFFILE *af, unsigned char *buf, uint64 pos,int count)
+int split_raw_write_internal2(AFFILE *af, unsigned char *buf, uint64 pos,size_t count)
 {
     struct split_raw_private *srp = SPLIT_RAW_PRIVATE(af);
     off_t c1, c3;
@@ -462,7 +462,7 @@ int split_raw_write_internal2(AFFILE *af, unsigned char *buf, uint64 pos,int cou
     return ret;
 }
 
-int split_raw_write(AFFILE *af, unsigned char *buf, uint64 pos,int count)
+int split_raw_write(AFFILE *af, unsigned char *buf, uint64 pos,size_t count)
 {
   /* If we are being asked to start writing beyond the end of the file
    * pad out the file (and possibly create one or more new image files.)
@@ -590,7 +590,7 @@ static int split_raw_update_seg(AFFILE *af, const char *name,
 
 struct af_vnode vnode_split_raw = {
     AF_IDENTIFY_SPLIT_RAW,
-    AF_VNODE_TYPE_COMPOUND,
+    AF_VNODE_TYPE_COMPOUND|AF_VNODE_TYPE_RELIABLE|AF_VNODE_MAXSIZE_MULTIPLE,
     "Split Raw",
     split_raw_identify_file,
     split_raw_open,
