@@ -267,10 +267,10 @@ int  compare_aff_data_segments(char *title,AFFILE *af1,AFFILE *af2,int64 pagenum
 {
     int ret = 0;
     char pagename[65];
-    sprintf(pagename,AF_PAGE,pagenum);
+    snprintf(pagename,sizeof(pagename),AF_PAGE,pagenum);
 
     char segname[65];
-    sprintf(segname,AF_SEG_D,pagenum);
+    snprintf(segname,sizeof(segname),AF_SEG_D,pagenum);
 
     unsigned long arg1=0;
     size_t data1_len=0;
@@ -351,19 +351,21 @@ int  compare_aff_data_segments(char *title,AFFILE *af1,AFFILE *af2,int64 pagenum
     char outline[256];
     outline[0] = 0;
     if(opt_all || (no_match>0) || af1_bad || af2_bad){
-	sprintf(outline,
+	snprintf(outline,sizeof(outline),
 		"   page%"I64d" sectors:%4d  matching: %3d  different:%3d",
 		pagenum,total_sectors,matching_sectors,no_match);
     }
     if(af1_bad){
-	sprintf(outline+strlen(outline),"    file 1 bad: %3d ",af1_bad);
+	snprintf(outline+strlen(outline),sizeof(outline)-strlen(outline),
+		 "    file 1 bad: %3d ",af1_bad);
     }
     if(af2_bad){
-	sprintf(outline+strlen(outline),"    file 2 bad: %3d ",af2_bad);
+	snprintf(outline+strlen(outline),sizeof(outline)-strlen(outline),
+		 "    file 2 bad: %3d ",af2_bad);
     }
     if(matching_bad_sectors){
 	if(opt_all){
-	    sprintf(outline+strlen(outline),
+	    snprintf(outline+strlen(outline),sizeof(outline)-strlen(outline),
 		    "    bad both:%3d ",matching_bad_sectors);
 	}
     }
@@ -609,11 +611,17 @@ int compare_aff_aff(const char *file1,const char *file2)
 	    char *title = "Metadata segments ";
 	    char mode_title[1024];
 	    switch(mode){
-	    case 1: sprintf(mode_title,"  %s only in %s:\n",
-			    title,af_filename(af1));break;
-	    case 2: sprintf(mode_title,"  %s only in %s:\n",
-			    title,af_filename(af2));break;
-	    case 3: sprintf(mode_title,"  %s in both files:\n",title);break;
+	    case 1:
+		snprintf(mode_title,sizeof(mode_title),"  %s only in %s:\n",
+			 title,af_filename(af1));
+		break;
+	    case 2:
+		snprintf(mode_title,sizeof(mode_title),"  %s only in %s:\n",
+			 title,af_filename(af2));
+		break;
+	    case 3:
+		snprintf(mode_title,sizeof(mode_title),"  %s in both files:\n",title);
+		break;
 	    }
 	    
 	    for(vector<string>::iterator i = segs.begin();i != segs.end();i++){
@@ -631,9 +639,11 @@ int compare_aff_aff(const char *file1,const char *file2)
     for(int mode=1;mode<=3;mode++){
 	char mode_title[1024];
 	switch(mode){
-	case 1: sprintf(mode_title,"  Pages only in %s:\n", af_filename(af1));break;
-	case 2: sprintf(mode_title,"  Pages only in %s:\n", af_filename(af2));break;
-	case 3: sprintf(mode_title,"  Pages in both files:\n");break;
+	case 1: snprintf(mode_title,sizeof(mode_title),
+			 "  Pages only in %s:\n", af_filename(af1));break;
+	case 2: snprintf(mode_title,sizeof(mode_title),
+			 "  Pages only in %s:\n", af_filename(af2));break;
+	case 3: snprintf(mode_title,sizeof(mode_title),"  Pages in both files:\n");break;
 	}
 	    
 	for(int i=lowest_page;i<=highest_page;i++){
@@ -657,9 +667,9 @@ int recurse(const char *dir1,const char *dir2)
 	char fn1[MAXPATHLEN+1]; memset(fn1,0,sizeof(fn1));
 	char fn2[MAXPATHLEN+1]; memset(fn2,0,sizeof(fn2));
 
-	strcpy(fn1,dir1);
-	if(fn1[strlen(fn1)-1]!='/') strcat(fn1,"/");
-	strcat(fn1,dp->d_name);
+	strlcpy(fn1,dir1,sizeof(fn1));
+	if(fn1[strlen(fn1)-1]!='/') strlcat(fn1,"/",sizeof(fn1));
+	strlcat(fn1,dp->d_name,sizeof(fn1));
 
 	current_source = fn1;
 	if(opt_verbose) printf("%s...\n",fn1);
@@ -672,9 +682,9 @@ int recurse(const char *dir1,const char *dir2)
 	case AF_IDENTIFY_AFF:
 	case AF_IDENTIFY_AFD:
 	case AF_IDENTIFY_AFM:
-	    strcpy(fn2,dir2);
-	    if(fn2[strlen(fn2)-1]!='/') strcat(fn2,"/");
-	    strcat(fn2,dp->d_name);
+	    strlcpy(fn2,dir2,sizeof(fn2));
+	    if(fn2[strlen(fn2)-1]!='/') strlcat(fn2,"/",sizeof(fn2));
+	    strlcat(fn2,dp->d_name,sizeof(fn2));
 	    if(af_identify_file_type(fn2,1)<0){
 		char buf[1024];
 		snprintf(buf,sizeof(buf),"%s not in %s\n",dp->d_name,dir2);
@@ -763,8 +773,8 @@ int main(int argc,char **argv)
 		if(cc) name1 = cc+1;
 
 		char file2[MAXPATHLEN+1];
-		strcpy(file2,last);
-		strcat(file2,name1);
+		strlcpy(file2,last,sizeof(file2));
+		strlcat(file2,name1,sizeof(file2));
 		int e_code = compare_aff_aff(file1,file2);
 		if(e_code) exit(e_code);
 		argv++;
