@@ -105,7 +105,7 @@ char    *command_line = 0;			// what is typed
 char *append(char *base,char *str)
 {
     base = (char *)realloc(base,strlen(base)+strlen(str)+1);
-    strcat(base,str);
+    strcat(base,str);			// can't fail
     return base;
 }
 
@@ -223,7 +223,7 @@ int convert(const char *infile,char *outfile)
 {
     if(opt_debug) fprintf(stderr,"convert(%s,%s)\n",infile,outfile);
     if(access(infile,F_OK)!=0){
-	err(1,infile);			// file does not exist?
+	err(1,"%s",infile);			// file does not exist?
     }
 
     if(infile && outfile && strcmp(infile,outfile)==0){
@@ -241,8 +241,9 @@ int convert(const char *infile,char *outfile)
     if(probe_gzip(infile)
        && yesno("infile looks like a gzip file","Uncompress it","Uncompressing")){
 	/* Open with a subprocess. We will need to use zlib when we move to Windows. */
+	if(af_hasmeta(infile)) return -1;	// don't covert with shell metacharacters
 	char buf[256];
-	sprintf(buf,"gzcat %s",infile);
+	snprintf(buf,sizeof(buf),"gzcat %s",infile);
 	a_in = af_popen(buf,"r");
     }
 
@@ -251,8 +252,9 @@ int convert(const char *infile,char *outfile)
        && probe_bzip2(infile)
        && yesno("infile looks like a bzip2 file","Uncompress it","Uncompressing")){
 	/* Open with a subprocess. We will need to use bzip2zlib when we move to Windows. */
+	if(af_hasmeta(infile)) return -1;	// don't covert with shell metacharacters
 	char buf[256];
-	sprintf(buf,"bzcat %s",infile);
+	snprintf(buf,sizeof(buf),"bzcat %s",infile);
 	a_in = af_popen(buf,"r");
     }
 
@@ -260,7 +262,7 @@ int convert(const char *infile,char *outfile)
     /* If the file isn't open, try to open it... */
     if(!a_in){
 	a_in = af_open(infile,O_RDONLY,0);
-	if(!a_in) err(1,infile);	// give up
+	if(!a_in) err(1,"%s",infile);	// give up
 	if(af_identify(a_in)==AF_IDENTIFY_RAW){	
 	    af_set_pagesize(a_in,image_pagesize); // match the page size we want to use
 	}
@@ -278,13 +280,26 @@ int convert(const char *infile,char *outfile)
 
     AFFILE *a_out = 0;			// output file, if aff or raw...
     if(access(outfile,F_OK)==0){
+	/* If outfile is a device, ask user... */
+	struct stat sb;
+	if(stat(outfile,&sb)){
+	    err(1,"%s exists but can't be stat?",outfile);
+	}
+	if((sb.st_mode & S_IFMT)==S_IFCHR ||
+	   (sb.st_mode & S_IFMT)==S_IFBLK){
+	    char buf[1024];
+	    snprintf(buf,sizeof(buf),"%s is a raw device.\n",outfile);
+	    if(yesno(buf,"Overwrite raw device?","yes")){
+		goto doit;
+	    }
+	}
 	fprintf(stderr,"%s: file exists. Delete it before converting.\n",outfile);
 	return -1;
     }
     /* Check for splitraw names */
     if(af_ext_is(outfile,"afm")){
 	char file000[MAXPATHLEN+1];
-	strcpy(file000,outfile);
+	strlcpy(file000,outfile,sizeof(file000));
 	char *cc = rindex(file000,'.');
 	if(!cc) err(1,"Cannot file '.' in %s\n",file000);
 	for(int i=0;i<2;i++){
@@ -297,12 +312,14 @@ int convert(const char *infile,char *outfile)
 	}
     }
 
+ doit:;
+
 
     if(opt_write_raw){
 	/* Easy way to make a raw output is to reopen an existing output file... */
 	FILE *f = fopen(outfile,"w+b");
 	if(!f){
-	    err(1,outfile);
+	    err(1,"%s",outfile);
 	}
 	a_out = af_freopen(f);
 
@@ -384,7 +401,7 @@ int convert(const char *infile,char *outfile)
 	for(vector<string>::iterator i = metadata_segments.begin();
 	    i != metadata_segments.end();
 	    i++){
-	    strcpy(segname,i->c_str());
+	    strlcpy(segname,i->c_str(),sizeof(segname));
 	    size_t data_len = 0;
 	    unsigned long arg;
 
@@ -662,23 +679,23 @@ int main(int argc,char **argv)
 
 	/* Check for "-o filename" to specify the output arg... */
 	if(argc>=2 && strcmp(*argv,"-o")==0){
-	    strcpy(outfile,argv[1]);
+	    strlcpy(outfile,argv[1],sizeof(outfile));
 	    argv += 2;
 	    argc -= 2;
 	}
 	else {
 
 	    /* Copy over the filename and change the extension */
-	    strcpy(outfile,infile);
+	    strlcpy(outfile,infile,sizeof(outfile));
 	    char *cc = rindex(outfile,'.'); // to strip off extension
 	    if(cc){
 		/* Found an extension; copy over mine. */
-		strcpy(cc+1,ext);
+		strlcpy(cc+1,ext,sizeof(outfile)-(cc-outfile));
 	    }
 	    else {
 		/* No extension; make one */
-		strcat(outfile,".");
-		strcat(outfile,ext);
+		strlcat(outfile,".",sizeof(outfile));
+		strlcat(outfile,ext,sizeof(outfile));
 	    }
 
 	    /* The user might want us to put things
@@ -688,14 +705,14 @@ int main(int argc,char **argv)
 		cc = rindex(outfile,'/');
 		char filename[PATH_MAX];
 		if(cc){
-		    strcpy(filename,cc+1);	// just the filename
+		    strlcpy(filename,cc+1,sizeof(filename));	// just the filename
 		}
 		else{
-		    strcpy(filename,outfile);	// the outfile is the filename
+		    strlcpy(filename,outfile,sizeof(filename));	// the outfile is the filename
 		}
-		strcpy(outfile,opt_outdir);
-		strcat(outfile,"/");
-		strcat(outfile,filename);
+		strlcpy(outfile,opt_outdir,sizeof(outfile));
+		strlcat(outfile,"/",sizeof(outfile));
+		strlcat(outfile,filename,sizeof(outfile));
 	    }
 	}
 	convert(infile,outfile);
