@@ -199,7 +199,7 @@ int afcopy(char *infile,vector<string> &outfiles)
     
     /* Open the input file */
     AFFILE *ain = af_open(infile,O_RDONLY,0);
-    if(!ain) err(1,infile);
+    if(!ain) err(1,"%s",infile);
     seglist segments;
     get_seglist(ain,&segments);
 
@@ -247,7 +247,7 @@ int afcopy(char *infile,vector<string> &outfiles)
 	if(out.af==0){
 	    out.af = af_open(fname,O_RDWR|O_EXCL|O_CREAT,0666);
 	    if(!out.af){
-		warn(fname);
+		warn("%s",fname);
 		continue;
 	    }
 	    if(af_set_pagesize(out.af,af_page_size(ain))){
@@ -377,7 +377,7 @@ int afcopy(char *infile,vector<string> &outfiles)
 		    /* Looks like a legacy segname name was renamed.
 		     * Try the new name
 		     */
-		    sprintf(b2,"page%s",segname+3);
+		    snprintf(b2,sizeof(b2),"page%s",segname+3);
 		    if(opt_verbose) printf("  Couldn't read %s; looking for %s\n",
 				       segname,b2);
 		    segname = b2;
