@@ -100,6 +100,7 @@ int opt_verbose = 0;
 int opt_y = 0;
 int opt_hexbuf = AF_HEXBUF_SPACE4 | AF_HEXBUF_UPPERCASE;
 int opt_page_validate = 0;
+int opt_no_data = 0;
 
 vector<string> opt_seglist;		// just info these segments
 
@@ -114,6 +115,7 @@ void usage()
     printf("   -w = wide output; print more than 1 line if necessary.\n");
     printf("   -s segment =   Just print information about 'segment'.\n");
     printf("                    (may be repeated)\n");
+    printf("   -X = no data preview; just print the segment names\n");
     printf("   -x = print binary values in hex (default is ASCII)\n");
     printf("   -m = validate MD5 hash of entire image\n");
     printf("   -S = validate SHA1 hash of entire image\n");
@@ -333,6 +335,20 @@ void print_info(AFFILE *af,const char *segname)
 	printf("%-25s  SEGMENT NOT FOUND\n",segname);
 	return;
     }
+
+    /* Start the output line */
+
+    char output_line[OUTLINE_LEN];		
+    memset(output_line,0,sizeof(output_line));
+
+    /* Now append the arg and the data len */
+    sprintf(output_line,"%-24s %8ld   %6ld   ",segname,arg,(long)data_len);
+
+    if(opt_no_data){
+	printf("%s\n",output_line);
+	return;
+    }
+
     unsigned char *data = (unsigned char *)malloc(data_len);
     if(af_get_seg(af,segname,0,data,&data_len)){
 	warn("af_get_seg_2");
@@ -340,12 +356,6 @@ void print_info(AFFILE *af,const char *segname)
 	return;
     }
 
-    char output_line[OUTLINE_LEN];		
-    memset(output_line,0,sizeof(output_line));
-
-    /* Now append the arg and the data len */
-    sprintf(output_line,"%-24s %6ld   %6ld   ",segname,arg,(long)data_len);
-
     /* Special handling of values that should be displayed as time */
     if(display_as_time(segname)){
 	int hours   = arg / 3600;
@@ -390,7 +400,8 @@ void print_info(AFFILE *af,const char *segname)
 
     if(display_as_hex(segname,display_len)){
 	char buf[80];
-	sprintf(cc,"%s%s",af_hexbuf(buf,sizeof(buf),data,display_len,opt_hexbuf),
+	snprintf(cc,sizeof(output_line)-strlen(output_line),
+		 "%s%s",af_hexbuf(buf,sizeof(buf),data,display_len,opt_hexbuf),
 		dots ? "..." : "");
 	/* Special code for SHA1 */
 	if(!opt_wide && strcmp(segname,AF_SHA1)==0){
@@ -482,9 +493,9 @@ int info_file(const char *infile)
 
     printf("\n%s\n",af_filename(af));
     if(opt_all==0) printf("[skipping data segments]\n");
-    printf("                                     data       \n");
-    printf("Segment                     arg    length    data\n");
-    printf("=======                 =======    ======    ====\n");
+    printf("                                      data       \n");
+    printf("Segment                       arg    length    data\n");
+    printf("=======                 =========    ======    ====\n");
 
     /* If a list of segments was specified by the user, just use that list */
     if(opt_seglist.size()>0){
@@ -520,11 +531,41 @@ int info_file(const char *infile)
 	print_info(af,i->c_str());
     }
     printf("\n");
-    printf("Page  segments:    %8lu\n",total_pages);
-    printf("Hash  segments:    %8lu\n",total_hashes);
-    printf("Empty segments:    %8lu\n",null_segs);
-    printf("Total segments:    %8lu\n", total_segs);
-    //printf("Compression ratio: %5.2g\n", total_bytes_compressed / total_bytes_uncompressed
+    printf("Page  segments:        %8lu\n",total_pages);
+    printf("Hash  segments:        %8lu\n",total_hashes);
+    printf("Total segments:        %8lu\n", total_segs);
+    //printf("Empty segments:        %8lu\n",null_segs);
+
+    int64 device_sectors = 0;
+    af_get_segq(af,AF_DEVICE_SECTORS,&device_sectors);
+    if(device_sectors==0){
+	/* See if we can fake it */
+	unsigned long cylinders=0;
+	unsigned long heads=0;
+	unsigned long sectors_per_track=0;
+	af_get_seg(af,AF_CYLINDERS,&cylinders,0,0);
+	af_get_seg(af,AF_HEADS,&heads,0,0);
+	af_get_seg(af,AF_SECTORS_PER_TRACK,&sectors_per_track,0,0);
+	device_sectors = cylinders * heads * sectors_per_track;
+    }
+    //printf("device_sectors=%qd\n",device_sectors);
+
+
+    if(af->image_pagesize && af->image_sectorsize && device_sectors){
+	int64 device_bytes = (int64)device_sectors * af->image_sectorsize;
+	int64 device_pages = (device_bytes+af->image_pagesize-1) / af->image_pagesize;
+	int64 missing_pages = device_pages - total_pages;
+	//printf("device_bytes=%qd\n",device_bytes);
+	//printf("device_pages=%qd\n",device_pages);
+	if(missing_pages!=0){
+	    printf("Missing page segments: %8"I64u"\n",missing_pages);
+	}
+    }
+    else{
+	printf("Cannot calculate missing pages\n");
+	printf("  device_sectors=%"I64d" image_pagesize=%"I64d" sectorsize=%d\n",
+	       device_sectors,af->image_pagesize,af->image_sectorsize);
+    }
     af_close(af);
     return 0;
 
@@ -542,12 +583,13 @@ int main(int argc,char **argv)
     cols = tgetnum("co");
 #endif
 
-    while ((ch = getopt(argc, argv, "abh?s:SmiIwj:pxV")) != -1) {
+    while ((ch = getopt(argc, argv, "abh?s:SmiIwj:pxVX")) != -1) {
 	switch (ch) {
 	case 'a': opt_all++; break;
 	case 'b': opt_all ++; opt_b   ++; break;
 	case 'i': opt_info=0; opt_identify = 1; break;
 	case 'w': opt_wide++; break;
+	case 'X': opt_no_data++;break;
 	case 'x': opt_x++; break;
 	case 'y': opt_y++; break;
 	case 'm': opt_validate |= VALIDATE_MD5; break;
@@ -581,7 +623,7 @@ int main(int argc,char **argv)
 	argc--;				// decrement argument counter
 	 
 	const char *name = af_identify_file_name(infile,1);
-	if(!name) err(1,infile);
+	if(!name) err(1,"%s",infile);
 
 	if(opt_identify) printf("%s is a %s file\n",infile,name);
 	 
