@@ -51,25 +51,17 @@
 #include "base64.h"
 #include "quads.h"
 
-#if 0
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <err.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include <limits.h>
-#include <string.h>
-#include <zlib.h>
-#include <openssl/md5.h>
-#include <openssl/sha.h>
-#include <assert.h>
+#if HAVE_CTYPE_H
+#include <ctype.h>
 #endif
 
-//#ifdef HAVE_CURSES_H
-//#include <curses.h>
-//#endif
+#if !defined(HAVE_ISALPHANUM) && defined(HAVE_ISALNUM)
+#define isalphanum(c) isalnum(c)
+#endif
+
+#if !defined(HAVE_ISALPHANUM) && !defined(HAVE_ISALNUM)
+#define isalphanum(c) (isalpha(c)||isdigit(c))
+#endif
 
 char *progname = "afxml";
 
@@ -103,7 +95,7 @@ int xml_info(const char *infile)
 {
     AFFILE *af = af_open(infile,O_RDONLY,0);
     if(!af){
-	warn(infile);
+	warn("%s",infile);
 	return -1;
     }
 
@@ -146,9 +138,9 @@ int xml_info(const char *infile)
 	    break;
 	}
 
-	/* Change '/' to '_' in segname if present */
+	/* Change bad characters in segname if present */
 	for(char *cc=segname;*cc;cc++){
-	    if(*cc=='/') *cc = '_';
+	    if(!isalphanum(*cc)) *cc = '_';
 	}
 
 	if(datalen==8 && (arg & AF_SEG_QUADWORD || display_as_quad(segname))){
