@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  * 
- * $Date: 2007/04/04 18:48:43 $
+ * $Date: 2007/04/25 21:46:05 $
  */
 #ifndef _AUX_LIB_H
 #define _AUX_LIB_H
@@ -11,6 +11,10 @@
 
 #include "tsk_os.h"
 
+#if !defined (TSK_WIN32)
+#include <sys/param.h>
+#endif
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -87,6 +91,11 @@ extern "C" {
     typedef unsigned long long ULLONG;
     typedef unsigned char UCHAR;
 
+#ifndef rounddown
+#define rounddown(x, y)	\
+    ((((x) % (y)) == 0) ? (x) : \
+    (roundup((x),(y)) - (y)))
+#endif
 
 
 /* Standard local variable sizes */
