@@ -1,13 +1,20 @@
 # Script for compiling and installing 'file'
 # as part of The Sleuth Kit
 #
-# $Date: 2006/12/06 17:32:51 $
+# $Date: 2007/03/29 20:41:55 $
 #
 cd file
 
 if (test -f './Makefile') then
 	true
 else
+    (touch Makefile.am && \
+     touch configure.in && \
+     touch aclocal.m4 && \
+     touch Makefile.in && \
+     touch config.h.in && \
+     touch configure) || (cd ..; exit $?)
+
 	if [ "x${CC}" = "x" ]; then
 		./configure             \
           --prefix=`cd ../..; pwd`    \
