@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2007/04/04 18:48:46 $
+ * $Date: 2007/04/20 21:49:30 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2007 Brian Carrier.  All rights reserved
@@ -74,7 +74,7 @@ nsrl_test(FILE * hFile)
 {
     char buf[TSK_HDB_MAXLEN];
 
-    fseek(hFile, 0, SEEK_SET);
+    fseeko(hFile, 0, SEEK_SET);
     if (NULL == fgets(buf, TSK_HDB_MAXLEN, hFile))
         return 0;
 
@@ -396,6 +396,7 @@ nsrl_makeindex(TSK_HDB_INFO * hdb_info, TSK_TCHAR * dbtype)
     memset(phash, '0', TSK_HDB_HTYPE_SHA1_LEN + 1);
 
     /* read the file */
+    fseek(hdb_info->hDb, 0, SEEK_SET);
     for (i = 0; NULL != fgets(buf, TSK_HDB_MAXLEN, hdb_info->hDb);
          offset += len, i++) {
 
@@ -522,7 +523,7 @@ nsrl_getentry(TSK_HDB_INFO * hdb_info, char *hash, OFF_T offset,
     }
 
     /* read the header line ... -- this should be done only once... */
-    fseek(hdb_info->hDb, 0, SEEK_SET);
+    fseeko(hdb_info->hDb, 0, SEEK_SET);
     if (NULL == fgets(buf, TSK_HDB_MAXLEN, hdb_info->hDb)) {
         tsk_error_reset();
         tsk_errno = TSK_ERR_HDB_READDB;
@@ -542,7 +543,7 @@ nsrl_getentry(TSK_HDB_INFO * hdb_info, char *hash, OFF_T offset,
     while (1) {
         size_t len;
 
-        if (0 != fseek(hdb_info->hDb, (long) offset, SEEK_SET)) {
+        if (0 != fseeko(hdb_info->hDb, offset, SEEK_SET)) {
             tsk_error_reset();
             tsk_errno = TSK_ERR_HDB_READDB;
             snprintf(tsk_errstr, TSK_ERRSTR_L,
