@@ -5,15 +5,15 @@
 
 #include <afflib.h>
 
-extern IMG_INFO *aff_open(const char **, IMG_INFO *);
+extern TSK_IMG_INFO *aff_open(const char **, TSK_IMG_INFO *);
 
 typedef struct IMG_AFF_INFO IMG_AFF_INFO;
 
 struct IMG_AFF_INFO {
-    IMG_INFO img_info;
+    TSK_IMG_INFO img_info;
     AFFILE *af_file;
     off_t seek_pos;
-    uint16_t type;		/* TYPE - uses AF_IDENTIFY_x values */
+    uint16_t type;              /* TYPE - uses AF_IDENTIFY_x values */
 };
 
 #endif
