@@ -2,7 +2,7 @@
  * The Sleuth Kit - Add on for EWF image support
  * Eye Witness Compression Format Support
  *
- * $Date: 2007/03/20 21:54:53 $
+ * $Date: 2007/06/05 20:04:41 $
  *
  * Joachim Metz <metz@studenten.net>
  * Copyright (c) 2006 Joachim Metz.  All rights reserved 
@@ -15,7 +15,7 @@
 
 #ifdef USE_LIBEWF
 
-#include "libewf.h"
+#include <libewf.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -27,7 +27,8 @@ extern "C" {
     struct IMG_EWF_INFO {
         TSK_IMG_INFO img_info;
         LIBEWF_HANDLE *handle;
-        char *md5hash;
+        char md5hash[LIBEWF_STRING_DIGEST_HASH_LENGTH_MD5];
+        int md5hash_isset;
     };
 
 #ifdef __cplusplus
