@@ -1,7 +1,7 @@
 # Script for compiling libewf
 # as part of The Sleuth Kit
 #
-# $Date: 2007/03/29 20:41:55 $
+# $Date: 2007/05/17 20:05:08 $
 #
 cd libewf
 if (test -f './Makefile') then
@@ -13,15 +13,15 @@ else
      touch Makefile.in && \
      touch config.h.in && \
      touch configure) || (cd ..; exit $?)
-    ./configure || (cd ..; exit $?)
+    ./configure --enable-shared=no || (cd ..; exit $?)
 fi
 
-make -C src libewf.a
+make -C libewf
 
-if (test -f 'src/libewf.a') then 
+if (test -f 'libewf/.libs/libewf.a') then 
     mkdir libewf-tsk
     if (test -d 'libewf-tsk') then
-	cp src/libewf.a libewf-tsk
+	cp libewf/.libs/libewf.a libewf-tsk
 	(cd libewf-tsk; ar x libewf.a; cd ..)
 	ar rv ../../lib/libtsk.a libewf-tsk/*.o
 	rm -rf libewf-tsk
@@ -31,7 +31,7 @@ if (test -f 'src/libewf.a') then
 	exit 1
     fi
 else
-    echo "Error: Missing src/libewf.a file"
+    echo "Error: Missing libewf/.libs/libewf.a file"
     cd ..
     exit 1
 fi
