@@ -181,8 +181,12 @@ const unsigned short _sch_istable[256] =
 #define ISPRINT(c)  _sch_test(c, _sch_isprint)
 
 #define bfd_boolean unsigned char
+#ifndef FALSE
 #define FALSE 0
+#endif
+#ifndef TRUE
 #define TRUE 1
+#endif
 char *program_name;
 
 /* End of stuff added by brian */
@@ -514,7 +518,7 @@ static void
 print_strings (const char *filename, FILE *stream, uint64_t address,
 	       uint64_t stop_point, int magiccount, char *magic)
 {
-  char *buf = (char *) mymalloc (sizeof (char) * (string_min + 1));
+  char *buf = (char *) tsk_malloc (sizeof (char) * (string_min + 1));
 
   while (1)
     {
